# latexify_py
Generates LaTeX math description from Python functions.

## FAQs
1. Which Python version? ... Using 3.6 AST.
2. GPT-3? ... No, rule-based.

## Example

[Google Colaboratory](https://colab.research.google.com/drive/1MuiawKpVIZ12MWwyYuzZHmbKThdM5wNJ?usp=sharing)
